#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-lsp-server
version:              1.1.4
visibility:           public
id:                   dhall-lsp-server-1.1.4-A1a7pOIXbxmCQ4SJfX0xkd
key:                  dhall-lsp-server-1.1.4-A1a7pOIXbxmCQ4SJfX0xkd
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriella Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  a521ba9ae138275567cacbe1e90eedbb
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-lsp-server-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.4-A1a7pOIXbxmCQ4SJfX0xkd
depends:
    aeson-2.2.2.0-CRLoVrOByflKEQQ5tNkVEn
    aeson-pretty-0.8.10-9dzc5aNofu3FP3zKb1fh7N base-4.18.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.6-GeHrdSdLM9aDTkOoliMVuY
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dhall-1.42.3-BqVNStpALLSC4fORH7JBon
    dhall-json-1.7.12-9tFGzOgrnZOEx7bnGqk1KI directory-1.3.8.5
    filepath-1.4.300.1 lens-5.3.4-BYF30fB8VOaHJCjgTCselD
    lsp-2.2.0.0-BSqEDlSiYylGTL7IpulVqX
    megaparsec-9.7.0-FrqBcE6xAtMAjUGpKC31HV mtl-2.3.1
    network-uri-2.6.4.2-DZsK30J0JA75RbwwKgdhQI
    prettyprinter-1.7.1-52j8P4oMnu1E1CFeo6hQyT text-2.0.2
    text-rope-0.3-D4VWlJ9HZlL5eDy3JmXWYJ transformers-0.6.1.0
    unordered-containers-0.2.20.1-170HxTRPWLJC6Js92iIt2k
    uri-encode-1.5.0.7-GK3UpNiCNsu21Sqmax35Xz

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

